# seso
**A Search and Sort Extension Module for Python**

## Install

### from source

```pip3 install seso```

## Tests

```python3 -m unittest discover tests```

## List of Implementations

- [Search](algorithms/search)
    - [linear search](seso/include/search/linearsearch.h)
    - [binary search](seso/include/search/binarysearch.h)
    - [jump search](seso/include/search/jumpsearch.h)
    - [interpolation search](seso/include/search/interpolationsearch.h)
    - [exponential search](seso/include/search/exponentialsearch.h)
    - [fibonacci search](seso/include/search/fibonaccisearch.h)
    - [ternary search](seso/include/search/ternarysearch.h)

- [Sort](algorithms/search)
    - [bubble sort](seso/include/sort/bubblesort.h)
    - [selection sort](seso/include/sort/selectionsort.h)
    - [insertion sort](seso/include/sort/insertionsort.h)
    - [merge sort](seso/include/sort/mergesort.h)
    - [quick sort](seso/include/sort/quicksort.h)
    - [heap sort](seso/include/sort/heapsort.h)
    - [radix sort](seso/include/sort/radixsort.h)
    - [bucket sort](seso/include/sort/bucketsort.h)

## [Documentation](https://github.com/AjithRamachandran/seso/tree/main/docs)
